@@ -107,7 +107,7 @@ class Department(Entity):
     def __hash__(self):
         """the overridden __hash__ method
         """
-        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
+        return super(Department, self).__hash__()
 
     @validates("members")
     def _validate_members(self, key, member):
